from __future__ import annotations

from mipac.models.lite.emoji import PartialCustomEmoji
from mipac.types.note import INoteUpdated, INoteUpdatedReaction


class PartialReaction:
    def __init__(self, reaction: INoteUpdated[INoteUpdatedReaction]) -> None:
        self.__reaction = reaction

    @property
    def reaction(self) -> str:
        return self.__reaction['body']['body']['reaction']

    @property
    def emoji(self) -> PartialCustomEmoji:
        return PartialCustomEmoji(self.__reaction['body']['body']['emoji'])

    @property
    def user_id(self) -> str:
        return self.__reaction['body']['user_id']



from ._version import get_versions

__title__ = 'mipac'
__author__ = 'yupix'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022-present yupix'
__author_email__ = 'yupi0982@outlook.jp'
__version__ = get_versions()['version']
del get_versions

__path__ = __import__('pkgutil').extend_path(__path__, __name__)

from .abc import *  # noqa: F403, F401
from .models import *  # noqa: F403, F401

from . import _version
__version__ = _version.get_versions()['version']



from __future__ import annotations

from mipac.types.emoji import ICustomEmojiLite


class PartialCustomEmoji:
    def __init__(self, emoji: ICustomEmojiLite) -> None:
        self.__emoji = emoji

    @property
    def name(self) -> str:
        return self.__emoji['name']

    @property
    def url(self) -> str:
        return self.__emoji['url']
